==> moodle-3.1.18.tgz: moodle/mod/label/lang/en/label.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'label', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package mod_label
 * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configdndmedia'] = 'Offer to create a label when media files are dragged & dropped onto a course';
$string['configdndresizeheight'] = 'When a label is created from a dragged & dropped image, resize it if it is higher than this many pixels (0 for no resize)';
$string['configdndresizewidth'] = 'When a label is created from a dragged & dropped image, resize it if it is wider than this many pixels (0 for no resize)';
$string['dndmedia'] = 'Media drag and drop';
$string['dndresizeheight'] = 'Resize drag and drop height';
$string['dndresizewidth'] = 'Resize drag and drop width';
$string['dnduploadlabel'] = 'Add media to course page';
$string['dnduploadlabeltext'] = 'Add a label to the course page';
$string['label:addinstance'] = 'Add a new label';
$string['labeltext'] = 'Label text';
$string['modulename'] = 'Label';
$string['modulename_help'] = 'The label module enables text and multimedia to be inserted into the course page in between links to other resources and activities. Labels are very versatile and can help to improve the appearance of a course if used thoughtfully.

Labels may be used

* To split up a long list of activities with a subheading or an image
* To display an embedded sound file or video directly on the course page
* To add a short description to a course section';
$string['modulename_link'] = 'mod/label/view';
$string['modulenameplural'] = 'Labels';
$string['pluginadministration'] = 'Label administration';
$string['pluginname'] = 'Label';
$string['search:activity'] = 'Label';

==> moodle-3.4.8.tgz: moodle/mod/label/lang/en/label.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'label', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package mod_label
 * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configdndmedia'] = 'Offer to create a label when media files are dragged & dropped onto a course';
$string['configdndresizeheight'] = 'When a label is created from a dragged & dropped image, resize it if it is higher than this many pixels (0 for no resize)';
$string['configdndresizewidth'] = 'When a label is created from a dragged & dropped image, resize it if it is wider than this many pixels (0 for no resize)';
$string['dndmedia'] = 'Media drag and drop';
$string['dndresizeheight'] = 'Resize drag and drop height';
$string['dndresizewidth'] = 'Resize drag and drop width';
$string['dnduploadlabel'] = 'Add media to course page';
$string['dnduploadlabeltext'] = 'Add a label to the course page';
$string['indicator:cognitivedepth'] = 'Label cognitive';
$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Label resource.';
$string['indicator:socialbreadth'] = 'Label social';
$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Label resource.';
$string['label:addinstance'] = 'Add a new label';
$string['label:view'] = 'View label';
$string['labeltext'] = 'Label text';
$string['modulename'] = 'Label';
$string['modulename_help'] = 'The label module enables text and multimedia to be inserted into the course page in between links to other resources and activities. Labels are very versatile and can help to improve the appearance of a course if used thoughtfully.

Labels may be used

* To split up a long list of activities with a subheading or an image
* To display an embedded sound file or video directly on the course page
* To add a short description to a course section';
$string['modulename_link'] = 'mod/label/view';
$string['modulenameplural'] = 'Labels';
$string['privacy:metadata'] = 'The mod_label plugin does not store any personal data.';
$string['pluginadministration'] = 'Label administration';
$string['pluginname'] = 'Label';
$string['search:activity'] = 'Label';
